from http import HTTPStatus
from typing import (  # noqa: Y022 # switching typing.type to builtins.type causes an import error
    Any,
    Callable,
    Type,
    TypeVar,
)

from marshmallow import Schema

_T = TypeVar("_T", bound=Callable[..., Any])

class ResponseMixin:
    def response(
        self,
        status_code: int | str | HTTPStatus,
        schema: Schema | Type[Schema] | None = ...,
        *,
        description: str | None = ...,
        example: dict[str, object] | None = ...,
        examples: dict[str, object] | None = ...,
        headers: dict[str, object] | None = ...
    ) -> Callable[[_T], _T]: ...
    def alt_response(
        self,
        status_code: int | str | HTTPStatus,
        response: str | None = ...,
        *,
        schema: Schema | Type[Schema] | None = ...,
        description: str | None = ...,
        example: dict[str, object] | None = ...,
        examples: dict[str, object] | None = ...,
        headers: dict[str, object] | None = ...,
        success: bool = ...
    ) -> Callable[[_T], _T]: ...



from typing import Any

from flask_smorest.exceptions import MissingAPIParameterError as MissingAPIParameterError
from flask_smorest.utils import prepare_response as prepare_response

from .constants import DEFAULT_REQUEST_BODY_CONTENT_TYPE as DEFAULT_REQUEST_BODY_CONTENT_TYPE
from .constants import DEFAULT_RESPONSE_CONTENT_TYPE as DEFAULT_RESPONSE_CONTENT_TYPE
from .field_converters import uploadfield2properties as uploadfield2properties
from .plugins import FlaskPlugin as FlaskPlugin

def __getattr__(name: str) -> Any: ...  # incomplete



from typing import Any, NoReturn

from apispec import APISpec  # type: ignore[import] # noqa: 723
from flask import Flask, Response

from .blueprint import Blueprint as Blueprint
from .error_handler import ErrorHandlerMixin
from .pagination import Page as Page
from .spec import APISpecMixin

__all__ = ["abort", "Api"]

def abort(http_status_code: int | Response, exc: Exception | None = ..., **kwargs: Any) -> NoReturn: ...

class Api(APISpecMixin, ErrorHandlerMixin):
    spec: APISpec

    def __init__(self, app: Flask | None = ..., *, spec_kwargs: Any = ...) -> None: ...
    def init_app(self, app: Flask, *, spec_kwargs: Any = ...) -> None: ...
    def register_blueprint(self, blp: Blueprint, *, parameters: list[Any] | None = ..., **options: Any) -> None: ...



from typing import Any

from .exceptions import NotModified as NotModified
from .exceptions import PreconditionFailed as PreconditionFailed
from .exceptions import PreconditionRequired as PreconditionRequired
from .utils import deepupdate as deepupdate
from .utils import get_appcontext as get_appcontext

def __getattr__(name: str) -> Any: ...  # incomplete



from collections import abc
from typing import Any, Callable, TypeVar

from _typeshed import Self
from flask import Blueprint as FlaskBlueprint

from .arguments import ArgumentsMixin as ArgumentsMixin
from .etag import EtagMixin as EtagMixin
from .pagination import PaginationMixin as PaginationMixin
from .response import ResponseMixin as ResponseMixin

def __getattr__(name: str) -> Any: ...  # incomplete

_T = TypeVar("_T", bound=Callable[..., Any])

class Blueprint(FlaskBlueprint, ArgumentsMixin, ResponseMixin, PaginationMixin, EtagMixin):
    HTTP_METHODS: list[str]
    DEFAULT_LOCATION_CONTENT_TYPE_MAPPING: dict[str, str]
    DOCSTRING_INFO_DELIMITER: str

    def __init__(
        self,
        name: str,
        import_name: str,
        *args: Any,
        url_prefix: str | None = ...,
        description: str | None = ...,
        **kwargs: Any
    ) -> None: ...
    @staticmethod
    def doc(**kwargs: str | abc.Mapping[str, Any]) -> Callable[[_T], _T]: ...
    def route(self, rule: str, *, parameters: Any = ..., tags: Any = ..., **options: Any) -> Callable[[_T], _T]: ...



from typing import (  # noqa: Y022 # switching typing.type to builtins.type causes an import error
    Any,
    Callable,
    Literal,
    Type,
    TypeVar,
)

from marshmallow import Schema

_T = TypeVar("_T", bound=Callable[..., Any])

class ArgumentsMixin:
    ARGUMENTS_PARSER: Any

    def arguments(
        self,
        schema: Schema | Type[Schema],
        *,
        location: Literal["json", "query", "querrystring", "path", "form", "headers", "cookies", "files"] = ...,
        content_type: str | None = ...,
        required: bool = ...,
        description: str | None = ...,
        example: dict[str, object] | None = ...,
        examples: dict[str, object] | None = ...,
        **kwargs: Any
    ) -> Callable[[_T], _T]: ...



"""A setuptools based setup module.
See:
https://packaging.python.org/guides/distributing-packages-using-setuptools/
https://github.com/pypa/sampleproject
Modified by Madoshakalaka@Github (dependency links added)
"""
from os import path

# Always prefer setuptools over distutils
from setuptools import find_packages, glob, setup

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, "README.md"), encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="types-smorest",
    # version="0.36.0.0", Reserved for final release, 0.0.X will be used for initial tests
    version="0.0.6",
    description="Type Stubs for flask-smorest",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/cex-solutions/types-smorest",
    author="Binovate Labs",
    author_email="cex-dev@binovate.com",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Framework :: Flask",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Typing :: Stubs Only",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
    ],
    license="GPLv3",
    keywords="flask flask-smorest smorest stubs",
    package_data={"flask_smorest-stubs": glob.glob("flask_smorest-stubs/**/*.pyi") + ["METADATA.toml"]},
    packages=["flask_smorest-stubs"],
    python_requires=">=3.7, <4",
    install_requires=[],
    extras_require={
        "dev": [
            "flask==2.0.2",
            "marshmallow==3.14.1",
            "apispec==5.1.1",
            "mypy==0.931",
            "pipenv-setup==3.1.4",
            "types-flask==1.1.6",
        ]
    },
    dependency_links=[],
    project_urls={
        "Bug Reports": "https://github.com/cex-solutions/types-smorest/issues",
        "Source": "https://github.com/cex-solutions/types-smorest",
    },
)
